@@ -3,7 +3,6 @@ package ingress
 import (
 	"fmt"
 	"reflect"
-	"strconv"
 	"testing"
 	"time"
 
@@ -32,6 +31,68 @@ var otherToleration = corev1.Toleration{
 	Effect:   corev1.TaintEffectNoExecute,
 }
 
+func checkDeploymentHasEnvVar(t *testing.T, deployment *appsv1.Deployment, name string, expectValue bool, expectedValue string) {
+	t.Helper()
+
+	var (
+		actualValue string
+		foundValue  bool
+	)
+	for _, envVar := range deployment.Spec.Template.Spec.Containers[0].Env {
+		if envVar.Name == name {
+			foundValue = true
+			actualValue = envVar.Value
+			break
+		}
+	}
+	switch {
+	case !expectValue && foundValue:
+		t.Errorf("router Deployment has unexpected %s setting: %q", name, actualValue)
+	case expectValue && !foundValue:
+		t.Errorf("router Deployment is missing %v", name)
+	case expectValue && expectedValue != actualValue:
+		t.Errorf("router Deployment has unexpected %s setting: expected %q, got %q", name, expectedValue, actualValue)
+	}
+}
+
+func checkDeploymentHasContainer(t *testing.T, deployment *appsv1.Deployment, name string, expect bool) {
+	t.Helper()
+
+	for _, container := range deployment.Spec.Template.Spec.Containers {
+		if container.Name == name {
+			if expect {
+				return
+			}
+			t.Errorf("router Deployment has unexpected %q container", name)
+		}
+	}
+	if expect {
+		t.Errorf("router Deployment has no %q container", name)
+	}
+}
+
+func checkRollingUpdateParams(t *testing.T, deployment *appsv1.Deployment, maxUnavailable intstr.IntOrString, maxSurge intstr.IntOrString) {
+	t.Helper()
+
+	params := deployment.Spec.Strategy.RollingUpdate
+	if params == nil {
+		t.Error("router Deployment does not specify rolling update parameters")
+		return
+	}
+
+	if params.MaxSurge == nil {
+		t.Errorf("router Deployment does not specify MaxSurge: %#v", params)
+	} else if *params.MaxSurge != maxSurge {
+		t.Errorf("router Deployment has unexpected MaxSurge value; expected %#v, got %#v", maxSurge, params.MaxSurge)
+	}
+
+	if params.MaxUnavailable == nil {
+		t.Errorf("router Deployment does not specify MaxUnavailable: %#v", params)
+	} else if *params.MaxUnavailable != maxUnavailable {
+		t.Errorf("router Deployment has unexpected MaxUnavailable value; expected %#v, got %#v", maxUnavailable, params.MaxUnavailable)
+	}
+}
+
 func TestDesiredRouterDeployment(t *testing.T) {
 	var one int32 = 1
 	ingressConfig := &configv1.Ingress{}
@@ -102,33 +163,11 @@ func TestDesiredRouterDeployment(t *testing.T) {
 		t.Errorf("router Deployment has wrong hash; expected: %s, got: %s", expectedHash, actualHash)
 	}
 
-	namespaceSelector := ""
-	for _, envVar := range deployment.Spec.Template.Spec.Containers[0].Env {
-		if envVar.Name == "NAMESPACE_LABELS" {
-			namespaceSelector = envVar.Value
-			break
-		}
-	}
-	if namespaceSelector == "" {
-		t.Error("router Deployment has no namespace selector")
-	} else if namespaceSelector != "foo=bar" {
-		t.Errorf("router Deployment has unexpected namespace selectors: %v",
-			namespaceSelector)
-	}
+	checkDeploymentHasEnvVar(t, deployment, WildcardRouteAdmissionPolicy, true, "false")
 
-	routeSelector := ""
-	for _, envVar := range deployment.Spec.Template.Spec.Containers[0].Env {
-		if envVar.Name == "ROUTE_LABELS" {
-			routeSelector = envVar.Value
-			break
-		}
-	}
-	if routeSelector == "" {
-		t.Error("router Deployment has no route selector")
-	} else if routeSelector != "baz=quux" {
-		t.Errorf("router Deployment has unexpected route selectors: %v",
-			routeSelector)
-	}
+	checkDeploymentHasEnvVar(t, deployment, "NAMESPACE_LABELS", true, "foo=bar")
+
+	checkDeploymentHasEnvVar(t, deployment, "ROUTE_LABELS", true, "baz=quux")
 
 	if deployment.Spec.Replicas == nil {
 		t.Error("router Deployment has nil replicas")
@@ -137,6 +176,8 @@ func TestDesiredRouterDeployment(t *testing.T) {
 		t.Errorf("expected replicas to be 1, got %d", *deployment.Spec.Replicas)
 	}
 
+	checkRollingUpdateParams(t, deployment, intstr.FromString("50%"), intstr.FromString("25%"))
+
 	if len(deployment.Spec.Template.Spec.NodeSelector) == 0 {
 		t.Error("router Deployment has no default node selector")
 	}
@@ -145,29 +186,9 @@ func TestDesiredRouterDeployment(t *testing.T) {
 			deployment.Spec.Template.Spec.Tolerations)
 	}
 
-	proxyProtocolEnabled := false
-	for _, envVar := range deployment.Spec.Template.Spec.Containers[0].Env {
-		if envVar.Name == "ROUTER_USE_PROXY_PROTOCOL" {
-			if v, err := strconv.ParseBool(envVar.Value); err == nil {
-				proxyProtocolEnabled = v
-			}
-			break
-		}
-	}
-	if proxyProtocolEnabled {
-		t.Errorf("router Deployment unexpected proxy protocol")
-	}
+	checkDeploymentHasEnvVar(t, deployment, "ROUTER_USE_PROXY_PROTOCOL", false, "")
 
-	canonicalHostname := ""
-	for _, envVar := range deployment.Spec.Template.Spec.Containers[0].Env {
-		if envVar.Name == "ROUTER_CANONICAL_HOSTNAME" {
-			canonicalHostname = envVar.Value
-			break
-		}
-	}
-	if canonicalHostname != "" {
-		t.Errorf("router Deployment has unexpected canonical hostname: %q", canonicalHostname)
-	}
+	checkDeploymentHasEnvVar(t, deployment, "ROUTER_CANONICAL_HOSTNAME", false, "")
 
 	if deployment.Spec.Template.Spec.Volumes[0].Secret == nil {
 		t.Error("router Deployment has no secret volume")
@@ -190,51 +211,26 @@ func TestDesiredRouterDeployment(t *testing.T) {
 		t.Errorf("expected empty readiness probe host, got %q", deployment.Spec.Template.Spec.Containers[0].ReadinessProbe.Handler.HTTPGet.Host)
 	}
 
-	for _, container := range deployment.Spec.Template.Spec.Containers {
-		if container.Name == "syslog" {
-			t.Errorf("router Deployment has unexpected syslog container: %#v", container)
-		}
-	}
+	checkDeploymentHasContainer(t, deployment, operatorv1.ContainerLoggingSidecarContainerName, false)
+	checkDeploymentHasEnvVar(t, deployment, "ROUTER_LOG_FACILITY", false, "")
+	checkDeploymentHasEnvVar(t, deployment, "ROUTER_LOG_LEVEL", false, "")
+	checkDeploymentHasEnvVar(t, deployment, "ROUTER_SYSLOG_ADDRESS", false, "")
+	checkDeploymentHasEnvVar(t, deployment, "ROUTER_SYSLOG_FORMAT", false, "")
 
-	ciphers := ""
-	for _, envVar := range deployment.Spec.Template.Spec.Containers[0].Env {
-		if envVar.Name == "ROUTER_CIPHERS" {
-			ciphers = envVar.Value
-			break
-		}
-	}
-	expectedCiphers := "foo:bar:baz"
-	if ciphers != expectedCiphers {
-		t.Errorf("router Deployment has unexpected ciphers: expected %q, got %q", expectedCiphers, ciphers)
-	}
+	checkDeploymentHasEnvVar(t, deployment, "ROUTER_CIPHERS", true, "foo:bar:baz")
 
-	tlsMinVersion := ""
-	for _, envVar := range deployment.Spec.Template.Spec.Containers[0].Env {
-		if envVar.Name == "SSL_MIN_VERSION" {
-			tlsMinVersion = envVar.Value
-			break
-		}
-	}
-	expectedTLSMinVersion := "TLSv1.1"
-	if tlsMinVersion != expectedTLSMinVersion {
-		t.Errorf("router Deployment has unexpected minimum TLS version: expected %q, got %q", expectedTLSMinVersion, tlsMinVersion)
-	}
+	checkDeploymentHasEnvVar(t, deployment, "SSL_MIN_VERSION", true, "TLSv1.1")
 
-	var ipv4v6Mode string
-	foundIPv4V6Mode := false
-	for _, envVar := range deployment.Spec.Template.Spec.Containers[0].Env {
-		if envVar.Name == "ROUTER_IP_V4_V6_MODE" {
-			foundIPv4V6Mode = true
-			ipv4v6Mode = envVar.Value
-			break
-		}
-	}
-	if foundIPv4V6Mode {
-		t.Errorf("router Deployment has unexpected ROUTER_IP_V4_V6_MODE setting: %q", ipv4v6Mode)
-	}
+	checkDeploymentHasEnvVar(t, deployment, "ROUTER_IP_V4_V6_MODE", false, "")
 
-	ingressConfig.Annotations = map[string]string{
-		EnableLoggingAnnotation: "debug",
+	ci.Spec.Logging = &operatorv1.IngressControllerLogging{
+		Access: &operatorv1.AccessLogging{
+			Destination: operatorv1.LoggingDestination{
+				Type:      operatorv1.ContainerLoggingDestinationType,
+				Container: &operatorv1.ContainerLoggingDestinationParameters{},
+			},
+			HttpLogFormat: "%ci:%cp [%t] %ft %b/%s %B %bq %HM %HU %HV",
+		},
 	}
 	ci.Spec.TLSSecurityProfile = &configv1.TLSSecurityProfile{
 		Type: configv1.TLSProfileCustomType,
@@ -249,6 +245,8 @@ func TestDesiredRouterDeployment(t *testing.T) {
 		{CIDR: "10.0.0.1/8"},
 		{CIDR: "2620:0:2d0:200::7/32"},
 	}
+	var expectedReplicas int32 = 8
+	ci.Spec.Replicas = &expectedReplicas
 	ci.Status.Domain = "example.com"
 	ci.Status.EndpointPublishingStrategy.Type = operatorv1.LoadBalancerServiceStrategyType
 	deployment, err = desiredRouterDeployment(ci, ingressControllerImage, infraConfig, ingressConfig, apiConfig, networkConfig)
@@ -262,6 +260,7 @@ func TestDesiredRouterDeployment(t *testing.T) {
 	} else if actualHash != expectedHash {
 		t.Errorf("router Deployment has wrong hash; expected: %s, got: %s", expectedHash, actualHash)
 	}
+	checkRollingUpdateParams(t, deployment, intstr.FromString("25%"), intstr.FromString("25%"))
 	if deployment.Spec.Template.Spec.HostNetwork != false {
 		t.Error("expected host network to be false")
 	}
@@ -272,85 +271,39 @@ func TestDesiredRouterDeployment(t *testing.T) {
 		t.Errorf("expected empty readiness probe host, got %q", deployment.Spec.Template.Spec.Containers[0].ReadinessProbe.Handler.HTTPGet.Host)
 	}
 
-	proxyProtocolEnabled = false
-	for _, envVar := range deployment.Spec.Template.Spec.Containers[0].Env {
-		if envVar.Name == "ROUTER_USE_PROXY_PROTOCOL" {
-			if v, err := strconv.ParseBool(envVar.Value); err == nil {
-				proxyProtocolEnabled = v
-			}
-			break
-		}
-	}
-	if !proxyProtocolEnabled {
-		t.Errorf("router Deployment expected proxy protocol")
-	}
+	checkDeploymentHasEnvVar(t, deployment, "ROUTER_USE_PROXY_PROTOCOL", true, "true")
 
-	canonicalHostname = ""
-	for _, envVar := range deployment.Spec.Template.Spec.Containers[0].Env {
-		if envVar.Name == "ROUTER_CANONICAL_HOSTNAME" {
-			canonicalHostname = envVar.Value
-			break
-		}
-	}
-	if canonicalHostname == "" {
-		t.Error("router Deployment has no canonical hostname")
-	} else if canonicalHostname != ci.Status.Domain {
-		t.Errorf("router Deployment has unexpected canonical hostname: %q, expected %q", canonicalHostname, ci.Status.Domain)
-	}
+	checkDeploymentHasEnvVar(t, deployment, "ROUTER_CANONICAL_HOSTNAME", true, ci.Status.Domain)
 
-	foundSyslogContainer := false
-	for _, container := range deployment.Spec.Template.Spec.Containers {
-		if container.Name == "syslog" {
-			foundSyslogContainer = true
-		}
-	}
-	if !foundSyslogContainer {
-		t.Error("router Deployment has no syslog container")
-	}
+	checkDeploymentHasContainer(t, deployment, operatorv1.ContainerLoggingSidecarContainerName, true)
+	checkDeploymentHasEnvVar(t, deployment, "ROUTER_LOG_FACILITY", false, "")
+	checkDeploymentHasEnvVar(t, deployment, "ROUTER_LOG_LEVEL", true, "debug")
+	checkDeploymentHasEnvVar(t, deployment, "ROUTER_SYSLOG_ADDRESS", true, "/var/lib/rsyslog/rsyslog.sock")
+	checkDeploymentHasEnvVar(t, deployment, "ROUTER_SYSLOG_FORMAT", true, `"%ci:%cp [%t] %ft %b/%s %B %bq %HM %HU %HV"`)
 
-	ciphers = ""
-	for _, envVar := range deployment.Spec.Template.Spec.Containers[0].Env {
-		if envVar.Name == "ROUTER_CIPHERS" {
-			ciphers = envVar.Value
-			break
-		}
-	}
-	expectedCiphers = "quux"
-	if ciphers != expectedCiphers {
-		t.Errorf("router Deployment has unexpected ciphers: expected %q, got %q", expectedCiphers, ciphers)
-	}
+	checkDeploymentHasEnvVar(t, deployment, "ROUTER_CIPHERS", true, "quux")
 
-	tlsMinVersion = ""
-	for _, envVar := range deployment.Spec.Template.Spec.Containers[0].Env {
-		if envVar.Name == "SSL_MIN_VERSION" {
-			tlsMinVersion = envVar.Value
-			break
-		}
-	}
 	// TODO: Update when haproxy is built with an openssl version that supports tls v1.3.
-	expectedTLSMinVersion = "TLSv1.2"
-	if tlsMinVersion != expectedTLSMinVersion {
-		t.Errorf("router Deployment has unexpected minimum TLS version: expected %q, got %q", expectedTLSMinVersion, tlsMinVersion)
-	}
+	checkDeploymentHasEnvVar(t, deployment, "SSL_MIN_VERSION", true, "TLSv1.2")
 
-	foundIPv4V6Mode = false
-	for _, envVar := range deployment.Spec.Template.Spec.Containers[0].Env {
-		if envVar.Name == "ROUTER_IP_V4_V6_MODE" {
-			foundIPv4V6Mode = true
-			ipv4v6Mode = envVar.Value
-			break
-		}
-	}
-	if !foundIPv4V6Mode {
-		t.Error("router Deployment is missing ROUTER_IP_V4_V6_MODE setting")
-	} else if ipv4v6Mode != "v4v6" {
-		t.Errorf("router Deployment has unexpected ROUTER_IP_V4_V6_MODE setting: %q", ipv4v6Mode)
-	}
+	checkDeploymentHasEnvVar(t, deployment, "ROUTER_IP_V4_V6_MODE", true, "v4v6")
 
 	secretName := fmt.Sprintf("secret-%v", time.Now().UnixNano())
 	ci.Spec.DefaultCertificate = &corev1.LocalObjectReference{
 		Name: secretName,
 	}
+	ci.Spec.Logging = &operatorv1.IngressControllerLogging{
+		Access: &operatorv1.AccessLogging{
+			Destination: operatorv1.LoggingDestination{
+				Type: operatorv1.SyslogLoggingDestinationType,
+				Syslog: &operatorv1.SyslogLoggingDestinationParameters{
+					Address:  "1.2.3.4",
+					Port:     uint32(12345),
+					Facility: "local2",
+				},
+			},
+		},
+	}
 	ci.Spec.NodePlacement = &operatorv1.NodePlacement{
 		NodeSelector: &metav1.LabelSelector{
 			MatchLabels: map[string]string{
@@ -359,13 +312,9 @@ func TestDesiredRouterDeployment(t *testing.T) {
 		},
 		Tolerations: []corev1.Toleration{toleration},
 	}
-	var expectedReplicas int32 = 3
+	expectedReplicas = 3
 	ci.Spec.Replicas = &expectedReplicas
 	ci.Status.EndpointPublishingStrategy.Type = operatorv1.HostNetworkStrategyType
-	delete(ingressConfig.Annotations, EnableLoggingAnnotation)
-	ci.Annotations = map[string]string{
-		EnableLoggingAnnotation: "debug",
-	}
 	networkConfig.Status.ClusterNetwork = []configv1.ClusterNetworkEntry{
 		{CIDR: "2620:0:2d0:200::7/32"},
 	}
@@ -393,6 +342,7 @@ func TestDesiredRouterDeployment(t *testing.T) {
 	if *deployment.Spec.Replicas != expectedReplicas {
 		t.Errorf("expected replicas to be %d, got %d", expectedReplicas, *deployment.Spec.Replicas)
 	}
+	checkRollingUpdateParams(t, deployment, intstr.FromString("25%"), intstr.FromInt(0))
 	if e, a := ingressControllerImage, deployment.Spec.Template.Spec.Containers[0].Image; e != a {
 		t.Errorf("expected router Deployment image %q, got %q", e, a)
 	}
@@ -415,29 +365,14 @@ func TestDesiredRouterDeployment(t *testing.T) {
 			secretName, deployment.Spec.Template.Spec.Volumes[0].Secret.SecretName)
 	}
 
-	foundSyslogContainer = false
-	for _, container := range deployment.Spec.Template.Spec.Containers {
-		if container.Name == "syslog" {
-			foundSyslogContainer = true
-		}
-	}
-	if !foundSyslogContainer {
-		t.Error("router Deployment has no syslog container")
-	}
+	checkDeploymentHasContainer(t, deployment, operatorv1.ContainerLoggingSidecarContainerName, false)
+	checkDeploymentHasEnvVar(t, deployment, "ROUTER_LOG_FACILITY", true, "local2")
+	checkDeploymentHasEnvVar(t, deployment, "ROUTER_LOG_LEVEL", true, "debug")
+	checkDeploymentHasEnvVar(t, deployment, "ROUTER_SYSLOG_ADDRESS", true, "1.2.3.4:12345")
+	checkDeploymentHasEnvVar(t, deployment, "ROUTER_SYSLOG_FORMAT", false, "")
 
-	foundIPv4V6Mode = false
-	for _, envVar := range deployment.Spec.Template.Spec.Containers[0].Env {
-		if envVar.Name == "ROUTER_IP_V4_V6_MODE" {
-			foundIPv4V6Mode = true
-			ipv4v6Mode = envVar.Value
-			break
-		}
-	}
-	if !foundIPv4V6Mode {
-		t.Error("router Deployment is missing ROUTER_IP_V4_V6_MODE setting")
-	} else if ipv4v6Mode != "v6" {
-		t.Errorf("router Deployment has unexpected ROUTER_IP_V4_V6_MODE setting: %q", ipv4v6Mode)
-	}
+	checkDeploymentHasEnvVar(t, deployment, "ROUTER_IP_V4_V6_MODE", true, "v6")
+	checkDeploymentHasEnvVar(t, deployment, RouterDisableHTTP2EnvName, true, "true")
 }
 
 func TestInferTLSProfileSpecFromDeployment(t *testing.T) {
@@ -476,7 +411,7 @@ func TestInferTLSProfileSpecFromDeployment(t *testing.T) {
 					},
 				},
 				{
-					Name: "syslog",
+					Name: "logs",
 				},
 			},
 			expected: &configv1.TLSProfileSpec{
@@ -685,6 +620,19 @@ func TestDeploymentConfigChanged(t *testing.T) {
 			},
 			expect: true,
 		},
+		{
+			description: "if ROUTER_ALLOW_WILDCARD_ROUTES changes",
+			mutate: func(deployment *appsv1.Deployment) {
+				envs := deployment.Spec.Template.Spec.Containers[0].Env
+				for i, env := range envs {
+					if env.Name == WildcardRouteAdmissionPolicy {
+						envs[i].Value = "true"
+					}
+				}
+				deployment.Spec.Template.Spec.Containers[0].Env = envs
+			},
+			expect: true,
+		},
 		{
 			description: "if NAMESPACE_LABELS is added",
 			mutate: func(deployment *appsv1.Deployment) {
@@ -728,12 +676,19 @@ func TestDeploymentConfigChanged(t *testing.T) {
 			expect: false,
 		},
 		{
-			description: "if the deployment strategy parameters are changed",
+			description: "if the rolling update strategy's max surge parameter is changed",
 			mutate: func(deployment *appsv1.Deployment) {
 				deployment.Spec.Strategy.RollingUpdate.MaxSurge = pointerTo(intstr.FromString("25%"))
 			},
 			expect: true,
 		},
+		{
+			description: "if the rolling update strategy's max unavailable parameter is changed",
+			mutate: func(deployment *appsv1.Deployment) {
+				deployment.Spec.Strategy.RollingUpdate.MaxUnavailable = pointerTo(intstr.FromString("50%"))
+			},
+			expect: true,
+		},
 		{
 			description: "if the deployment template affinity is deleted",
 			mutate: func(deployment *appsv1.Deployment) {
@@ -771,6 +726,38 @@ func TestDeploymentConfigChanged(t *testing.T) {
 			},
 			expect: false,
 		},
+		{
+			description: "if probe values are set to default values",
+			mutate: func(deployment *appsv1.Deployment) {
+				deployment.Spec.Template.Spec.Containers[0].LivenessProbe.Handler.HTTPGet.Scheme = "HTTP"
+				deployment.Spec.Template.Spec.Containers[0].LivenessProbe.TimeoutSeconds = int32(1)
+				deployment.Spec.Template.Spec.Containers[0].LivenessProbe.PeriodSeconds = int32(10)
+				deployment.Spec.Template.Spec.Containers[0].LivenessProbe.SuccessThreshold = int32(1)
+				deployment.Spec.Template.Spec.Containers[0].LivenessProbe.FailureThreshold = int32(3)
+				deployment.Spec.Template.Spec.Containers[0].ReadinessProbe.Handler.HTTPGet.Scheme = "HTTP"
+				deployment.Spec.Template.Spec.Containers[0].ReadinessProbe.TimeoutSeconds = int32(1)
+				deployment.Spec.Template.Spec.Containers[0].ReadinessProbe.PeriodSeconds = int32(10)
+				deployment.Spec.Template.Spec.Containers[0].ReadinessProbe.SuccessThreshold = int32(1)
+				deployment.Spec.Template.Spec.Containers[0].ReadinessProbe.FailureThreshold = int32(3)
+			},
+			expect: false,
+		},
+		{
+			description: "if probe values are set to non-default values",
+			mutate: func(deployment *appsv1.Deployment) {
+				deployment.Spec.Template.Spec.Containers[0].LivenessProbe.Handler.HTTPGet.Scheme = "HTTPS"
+				deployment.Spec.Template.Spec.Containers[0].LivenessProbe.TimeoutSeconds = int32(2)
+				deployment.Spec.Template.Spec.Containers[0].LivenessProbe.PeriodSeconds = int32(20)
+				deployment.Spec.Template.Spec.Containers[0].LivenessProbe.SuccessThreshold = int32(2)
+				deployment.Spec.Template.Spec.Containers[0].LivenessProbe.FailureThreshold = int32(30)
+				deployment.Spec.Template.Spec.Containers[0].ReadinessProbe.Handler.HTTPGet.Scheme = "HTTPS"
+				deployment.Spec.Template.Spec.Containers[0].ReadinessProbe.TimeoutSeconds = int32(2)
+				deployment.Spec.Template.Spec.Containers[0].ReadinessProbe.PeriodSeconds = int32(20)
+				deployment.Spec.Template.Spec.Containers[0].ReadinessProbe.SuccessThreshold = int32(2)
+				deployment.Spec.Template.Spec.Containers[0].ReadinessProbe.FailureThreshold = int32(30)
+			},
+			expect: true,
+		},
 	}
 
 	for _, tc := range testCases {
@@ -827,12 +814,36 @@ func TestDeploymentConfigChanged(t *testing.T) {
 										Name:  "ROUTER_USE_PROXY_PROTOCOL",
 										Value: "false",
 									},
+									{
+										Name:  "ROUTER_ALLOW_WILDCARD_ROUTES",
+										Value: "false",
+									},
 									{
 										Name:  "ROUTE_LABELS",
 										Value: "foo=bar",
 									},
 								},
 								Image: "openshift/origin-cluster-ingress-operator:v4.0",
+								LivenessProbe: &corev1.Probe{
+									Handler: corev1.Handler{
+										HTTPGet: &corev1.HTTPGetAction{
+											Path: "/healthz",
+											Port: intstr.IntOrString{
+												IntVal: int32(1936),
+											},
+										},
+									},
+								},
+								ReadinessProbe: &corev1.Probe{
+									Handler: corev1.Handler{
+										HTTPGet: &corev1.HTTPGetAction{
+											Path: "/healthz/ready",
+											Port: intstr.IntOrString{
+												IntVal: int32(1936),
+											},
+										},
+									},
+								},
 							},
 						},
 						Affinity: &corev1.Affinity{
