@@ -14,6 +14,7 @@ import (
 
 	"k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/apimachinery/pkg/util/intstr"
 )
 
 // ensureRouterPodDisruptionBudget ensures the pod disruption budget exists for
@@ -34,17 +35,18 @@ func (r *reconciler) ensureRouterPodDisruptionBudget(ic *operatorv1.IngressContr
 	case !wantPDB && !havePDB:
 		return false, nil, nil
 	case !wantPDB && havePDB:
-		if deleted, err := r.deleteRouterPodDisruptionBudget(current); err != nil {
-			return true, current, fmt.Errorf("failed to delete pod disruption budget: %v", err)
-		} else if deleted {
+		if err := r.client.Delete(context.TODO(), current); err != nil {
+			if !errors.IsNotFound(err) {
+				return true, current, fmt.Errorf("failed to delete pod disruption budget: %v", err)
+			}
+		} else {
 			log.Info("deleted pod disruption budget", "poddisruptionbudget", current)
 		}
 	case wantPDB && !havePDB:
-		if created, err := r.createRouterPodDisruptionBudget(desired); err != nil {
+		if err := r.client.Create(context.TODO(), desired); err != nil {
 			return false, nil, fmt.Errorf("failed to create pod disruption budget: %v", err)
-		} else if created {
-			log.Info("created pod disruption budget", "poddisruptionbudget", desired)
 		}
+		log.Info("created pod disruption budget", "poddisruptionbudget", desired)
 	case wantPDB && havePDB:
 		if updated, err := r.updateRouterPodDisruptionBudget(current, desired); err != nil {
 			return true, nil, fmt.Errorf("failed to update pod disruption budget: %v", err)
@@ -60,10 +62,32 @@ func (r *reconciler) ensureRouterPodDisruptionBudget(ic *operatorv1.IngressContr
 // budget.  Returns a Boolean indicating whether a PDB is desired, as well as
 // the PDB if one is desired.
 func desiredRouterPodDisruptionBudget(ic *operatorv1.IngressController, deploymentRef metav1.OwnerReference) (bool, *policyv1beta1.PodDisruptionBudget, error) {
-	// Always return false because we never want a pod disruption budget.
-	// TODO: We removed pod disruption budgets in OpenShift 4.3; we should
-	// remove ensureRouterPodDisruptionBudget in OpenShift 4.4.
-	return false, nil, nil
+	if ic.Spec.Replicas != nil && *ic.Spec.Replicas < int32(2) {
+		return false, nil, nil
+	}
+
+	maxUnavailable := "50%"
+	if ic.Spec.Replicas != nil && int(*ic.Spec.Replicas) >= 4 {
+		maxUnavailable = "25%"
+	}
+
+	name := controller.RouterPodDisruptionBudgetName(ic)
+	pointerTo := func(ios intstr.IntOrString) *intstr.IntOrString { return &ios }
+	pdb := policyv1beta1.PodDisruptionBudget{
+		ObjectMeta: metav1.ObjectMeta{
+			Name:      name.Name,
+			Namespace: name.Namespace,
+		},
+		Spec: policyv1beta1.PodDisruptionBudgetSpec{
+			// The disruption controller rounds MaxUnavailable up.
+			// https://github.com/kubernetes/kubernetes/blob/65dc445aa2d581b4fa829258e46e4faf44e999b6/pkg/controller/disruption/disruption.go#L539
+			MaxUnavailable: pointerTo(intstr.FromString(maxUnavailable)),
+			Selector:       controller.IngressControllerDeploymentPodSelector(ic),
+		},
+	}
+	pdb.SetOwnerReferences([]metav1.OwnerReference{deploymentRef})
+
+	return true, &pdb, nil
 }
 
 // currentRouterPodDisruptionBudget returns the current router pod disruption
@@ -80,27 +104,6 @@ func (r *reconciler) currentRouterPodDisruptionBudget(ic *operatorv1.IngressCont
 	return true, pdb, nil
 }
 
-// createRouterPodDisruptionBudget creates a pod disruption budget.  Returns a
-// Boolean indicating whether the PDB was created, and an error value.
-func (r *reconciler) createRouterPodDisruptionBudget(pdb *policyv1beta1.PodDisruptionBudget) (bool, error) {
-	if err := r.client.Create(context.TODO(), pdb); err != nil {
-		return false, err
-	}
-	return true, nil
-}
-
-// deleteRouterPodDisruptionBudget deletes a pod disruption budget.  Returns a
-// Boolean indicating whether the PDB was deleted, and an error value.
-func (r *reconciler) deleteRouterPodDisruptionBudget(pdb *policyv1beta1.PodDisruptionBudget) (bool, error) {
-	if err := r.client.Delete(context.TODO(), pdb); err != nil {
-		if errors.IsNotFound(err) {
-			return false, nil
-		}
-		return false, err
-	}
-	return true, nil
-}
-
 // updateRouterPodDisruptionBudget updates a pod disruption budget.  Returns a
 // Boolean indicating whether the PDB was updated, and an error value.
 func (r *reconciler) updateRouterPodDisruptionBudget(current, desired *policyv1beta1.PodDisruptionBudget) (bool, error) {
@@ -115,8 +118,8 @@ func (r *reconciler) updateRouterPodDisruptionBudget(current, desired *policyv1b
 	return true, nil
 }
 
-// podDisruptionBudgetChanged checks if current pod disruption budget spec
-// matches the expected spec and if not returns an updated one.
+// podDisruptionBudgetChanged checks whether the current pod disruption budget
+// spec matches the expected spec and if not returns an updated one.
 func podDisruptionBudgetChanged(current, expected *policyv1beta1.PodDisruptionBudget) (bool, *policyv1beta1.PodDisruptionBudget) {
 	if cmp.Equal(current.Spec, expected.Spec, cmpopts.EquateEmpty()) {
 		return false, nil
