@@ -3,6 +3,7 @@
 package e2e
 
 import (
+	"bufio"
 	"context"
 	"crypto/tls"
 	"crypto/x509"
@@ -13,6 +14,7 @@ import (
 	"os"
 	"reflect"
 	"strconv"
+	"strings"
 	"testing"
 	"time"
 
@@ -194,10 +196,6 @@ func TestUpdateDefaultIngressController(t *testing.T) {
 		t.Fatalf("failed to observe expected conditions: %v", err)
 	}
 
-	routerCAConfigmap := &corev1.ConfigMap{}
-	if err := kclient.Get(context.TODO(), controller.RouterCAConfigMapName(), routerCAConfigmap); err != nil {
-		t.Fatalf("failed to get CA certificate configmap: %v", err)
-	}
 	defaultIngressCAConfigmap := &corev1.ConfigMap{}
 	if err := kclient.Get(context.TODO(), controller.DefaultIngressCertConfigMapName(), defaultIngressCAConfigmap); err != nil {
 		t.Fatalf("failed to get CA certificate configmap: %v", err)
@@ -248,19 +246,6 @@ func TestUpdateDefaultIngressController(t *testing.T) {
 		t.Fatalf("failed to observe updated deployment: %v", err)
 	}
 
-	// Wait for the CA certificate configmap to be deleted.
-	err = wait.PollImmediate(1*time.Second, 10*time.Second, func() (bool, error) {
-		if err := kclient.Get(context.TODO(), controller.RouterCAConfigMapName(), routerCAConfigmap); err != nil {
-			if errors.IsNotFound(err) {
-				return true, nil
-			}
-			t.Logf("failed to get CA certificate configmap, will retry: %v", err)
-		}
-		return false, nil
-	})
-	if err != nil {
-		t.Fatalf("failed to observe clean-up of CA certificate configmap: %v", err)
-	}
 	// Wait for the default ingress configmap to be updated
 	previousDefaultIngressCAConfigmap := defaultIngressCAConfigmap.DeepCopy()
 	err = wait.PollImmediate(1*time.Second, 10*time.Second, func() (bool, error) {
@@ -285,19 +270,6 @@ func TestUpdateDefaultIngressController(t *testing.T) {
 		t.Errorf("failed to reset default ingresscontroller: %v", err)
 	}
 
-	// Wait for the CA certificate configmap to be recreated.
-	err = wait.PollImmediate(1*time.Second, 10*time.Second, func() (bool, error) {
-		if err := kclient.Get(context.TODO(), controller.RouterCAConfigMapName(), routerCAConfigmap); err != nil {
-			if !errors.IsNotFound(err) {
-				t.Logf("failed to get CA certificate configmap, will retry: %v", err)
-			}
-			return false, nil
-		}
-		return true, nil
-	})
-	if err != nil {
-		t.Fatalf("failed to get recreated CA certificate configmap: %v", err)
-	}
 	// Wait for the default ingress configmap to be updated back to the original
 	previousDefaultIngressCAConfigmap = defaultIngressCAConfigmap.DeepCopy()
 	err = wait.PollImmediate(1*time.Second, 10*time.Second, func() (bool, error) {
@@ -344,7 +316,7 @@ func TestIngressControllerScale(t *testing.T) {
 	}
 
 	oldRsList := &appsv1.ReplicaSetList{}
-	if err := kclient.List(context.TODO(), oldRsList, client.MatchingLabelsSelector{selector}); err != nil {
+	if err := kclient.List(context.TODO(), oldRsList, client.MatchingLabelsSelector{Selector: selector}); err != nil {
 		t.Fatalf("failed to list replicasets for ingresscontroller: %v", err)
 	}
 
@@ -353,7 +325,7 @@ func TestIngressControllerScale(t *testing.T) {
 		Resource: "ingresscontrollers",
 	}
 
-	scale, err := scaleClient.Scales(defaultName.Namespace).Get(resource, defaultName.Name)
+	scale, err := scaleClient.Scales(defaultName.Namespace).Get(context.TODO(), resource, defaultName.Name, metav1.GetOptions{})
 	if err != nil {
 		t.Fatalf("failed to get initial scale of default ingresscontroller: %v", err)
 	}
@@ -367,7 +339,7 @@ func TestIngressControllerScale(t *testing.T) {
 	newReplicas := originalReplicas + 1
 
 	scale.Spec.Replicas = newReplicas
-	updatedScale, err := scaleClient.Scales(defaultName.Namespace).Update(resource, scale)
+	updatedScale, err := scaleClient.Scales(defaultName.Namespace).Update(context.TODO(), resource, scale, metav1.UpdateOptions{})
 	if err != nil {
 		t.Fatalf("failed to scale ingresscontroller up: %v", err)
 	}
@@ -386,12 +358,12 @@ func TestIngressControllerScale(t *testing.T) {
 	}
 
 	// Scale back down.
-	scale, err = scaleClient.Scales(defaultName.Namespace).Get(resource, defaultName.Name)
+	scale, err = scaleClient.Scales(defaultName.Namespace).Get(context.TODO(), resource, defaultName.Name, metav1.GetOptions{})
 	if err != nil {
 		t.Fatalf("failed to get updated scale of ClusterIngress: %v", err)
 	}
 	scale.Spec.Replicas = originalReplicas
-	updatedScale, err = scaleClient.Scales(defaultName.Namespace).Update(resource, scale)
+	updatedScale, err = scaleClient.Scales(defaultName.Namespace).Update(context.TODO(), resource, scale, metav1.UpdateOptions{})
 	if err != nil {
 		t.Fatalf("failed to scale ingresscontroller down: %v", err)
 	}
@@ -413,7 +385,7 @@ func TestIngressControllerScale(t *testing.T) {
 	// Ensure the deployment did not create a new replicaset
 	// (see <https://bugzilla.redhat.com/show_bug.cgi?id=1783007>).
 	newRsList := &appsv1.ReplicaSetList{}
-	if err := kclient.List(context.TODO(), newRsList, client.MatchingLabelsSelector{selector}); err != nil {
+	if err := kclient.List(context.TODO(), newRsList, client.MatchingLabelsSelector{Selector: selector}); err != nil {
 		t.Fatalf("failed to list replicasets for ingresscontroller: %v", err)
 	}
 	oldRsIds := sets.String{}
@@ -449,7 +421,9 @@ func getScaleClient() (scale.ScalesGetter, error) {
 	return scale.NewForConfig(kubeConfig, restMapper, dynamic.LegacyAPIPathResolverFunc, scaleKindResolver)
 }
 
-func TestRouterCACertificate(t *testing.T) {
+// TestDefaultIngressCertificate verifies that the "default-ingress-cert"
+// configmap is published and can be used to connect to the router.
+func TestDefaultIngressCertificate(t *testing.T) {
 	ic := &operatorv1.IngressController{}
 	if err := kclient.Get(context.TODO(), defaultName, ic); err != nil {
 		t.Fatalf("failed to get default ingresscontroller: %v", err)
@@ -464,22 +438,16 @@ func TestRouterCACertificate(t *testing.T) {
 		t.Fatalf("failed to observe expected conditions: %v", err)
 	}
 
+	defaultIngressCAConfigmap := &corev1.ConfigMap{}
+	if err := kclient.Get(context.TODO(), controller.DefaultIngressCertConfigMapName(), defaultIngressCAConfigmap); err != nil {
+		t.Fatalf("failed to get CA certificate configmap: %v", err)
+	}
+
 	var certData []byte
-	err := wait.PollImmediate(1*time.Second, 10*time.Second, func() (bool, error) {
-		cm := &corev1.ConfigMap{}
-		err := kclient.Get(context.TODO(), controller.RouterCAConfigMapName(), cm)
-		if err != nil {
-			return false, nil
-		}
-		if val, ok := cm.Data["ca-bundle.crt"]; !ok {
-			return false, fmt.Errorf("router-ca secret is missing %q", "ca-bundle.crt")
-		} else {
-			certData = []byte(val)
-		}
-		return true, nil
-	})
-	if err != nil {
-		t.Fatalf("failed to get CA certificate: %v", err)
+	if val, ok := defaultIngressCAConfigmap.Data["ca-bundle.crt"]; !ok {
+		t.Fatalf("%s configmap is missing %q", controller.DefaultIngressCertConfigMapName(), "ca-bundle.crt")
+	} else {
+		certData = []byte(val)
 	}
 
 	certPool := x509.NewCertPool()
@@ -489,8 +457,7 @@ func TestRouterCACertificate(t *testing.T) {
 
 	wildcardRecordName := controller.WildcardDNSRecordName(ic)
 	wildcardRecord := &iov1.DNSRecord{}
-	err = kclient.Get(context.TODO(), wildcardRecordName, wildcardRecord)
-	if err != nil {
+	if err := kclient.Get(context.TODO(), wildcardRecordName, wildcardRecord); err != nil {
 		t.Fatalf("failed to get wildcard dnsrecord %s: %v", wildcardRecordName, err)
 	}
 	// TODO: handle >0 targets
@@ -525,9 +492,9 @@ func TestRouterCACertificate(t *testing.T) {
 	}
 }
 
-// TestPodDisruptionBudgetDoesNotExist verifies that a PodDisruptionBudget
-// resource does not exist for the default ingresscontroller.
-func TestPodDisruptionBudgetDoesNotExist(t *testing.T) {
+// TestPodDisruptionBudgetExists verifies that a PodDisruptionBudget resource
+// exists for the default ingresscontroller.
+func TestPodDisruptionBudgetExists(t *testing.T) {
 	ic := &operatorv1.IngressController{}
 	if err := kclient.Get(context.TODO(), defaultName, ic); err != nil {
 		t.Fatalf("failed to get default ingresscontroller: %v", err)
@@ -539,10 +506,7 @@ func TestPodDisruptionBudgetDoesNotExist(t *testing.T) {
 
 	pdb := &policyv1beta1.PodDisruptionBudget{}
 	if err := kclient.Get(context.TODO(), controller.RouterPodDisruptionBudgetName(ic), pdb); err != nil {
-		if errors.IsNotFound(err) {
-			return
-		}
-		t.Errorf("error getting default ingresscontroller poddisruptionbudget: %v", err)
+		t.Fatalf("failed to get default ingresscontroller poddisruptionbudget: %v", err)
 	}
 }
 
@@ -803,17 +767,313 @@ func TestRouteAdmissionPolicy(t *testing.T) {
 
 	// Update the ingresscontroller to a different route admission policy
 	if err := kclient.Get(context.TODO(), icName, ic); err != nil {
-		t.Fatalf("failed to get ingresscontroller: %v", ic)
+		t.Fatalf("failed to get ingresscontroller: %v", err)
 	}
 	ic.Spec.RouteAdmission.NamespaceOwnership = operatorv1.InterNamespaceAllowedOwnershipCheck
 	if err := kclient.Update(context.TODO(), ic); err != nil {
 		t.Fatalf("failed to update ingresscontroller: %v", err)
 	}
 
+	// The updated ingresscontroller deployment may take a few minutes to
+	// roll out, so make sure that it is updated, and then make sure that it
+	// has finished rolling out before checking the route.
+	err := wait.PollImmediate(1*time.Second, 1*time.Minute, func() (bool, error) {
+		deployment := &appsv1.Deployment{}
+		if err := kclient.Get(context.TODO(), controller.RouterDeploymentName(ic), deployment); err != nil {
+			return false, err
+		}
+		for _, v := range deployment.Spec.Template.Spec.Containers[0].Env {
+			if v.Name == "ROUTER_DISABLE_NAMESPACE_OWNERSHIP_CHECK" {
+				return strconv.ParseBool(v.Value)
+			}
+		}
+		return false, nil
+	})
+	if err != nil {
+		t.Fatalf("failed to observe ROUTER_DISABLE_NAMESPACE_OWNERSHIP_CHECK=true: %v", err)
+	}
+	if err := waitForIngressControllerCondition(kclient, 3*time.Minute, icName, conditions...); err != nil {
+		t.Fatalf("failed to observe expected conditions: %v", err)
+	}
+
 	// The second route should eventually be admitted because of the new policy
 	if err := waitForRouteIngressConditions(kclient, route2Name, ic.Name, admittedCondition); err != nil {
 		t.Fatalf("failed to observe expected conditions: %v", err)
 	}
+
+	// Test the ingress controller wildcard admission policy. An ingress controller with
+	// a nil wildcard policy defaults to WildcardsDisallowed and the default wildcard
+	// policy of a route is None. Therefore, the tests above cover defaulting behavior.
+	// Create a route that explicitly sets the wildcard policy to None.
+	route3Name := types.NamespacedName{Namespace: ns2.Name, Name: "route3"}
+	route3 := makeRoute(route3Name, "route3.test.example.com", "/bar")
+	route3.Spec.WildcardPolicy = routev1.WildcardPolicyNone
+
+	// The route should be admitted because the default ingresscontroller wildcard
+	// policy is WildcardsDisallowed.
+	if err := kclient.Create(context.TODO(), route3); err != nil {
+		t.Fatalf("failed to create route: %v", err)
+	}
+	if err := waitForRouteIngressConditions(kclient, route3Name, ic.Name, admittedCondition); err != nil {
+		t.Fatalf("failed to observe expected conditions: %v, status: %v", err, route3)
+	}
+
+	// Create a route with a wildcard policy of Subdomain.
+	route4Name := types.NamespacedName{Namespace: ns2.Name, Name: "route4"}
+	route4 := makeRoute(route4Name, "route4.test.example.com", "/bar")
+	route4.Spec.WildcardPolicy = routev1.WildcardPolicySubdomain
+
+	// The route should not be admitted because the ingresscontroller wildcard policy
+	// is WildcardsDisallowed by default.
+	if err := kclient.Create(context.TODO(), route4); err != nil {
+		t.Fatalf("failed to create route: %v", err)
+	}
+	if err := waitForRouteIngressConditions(kclient, route4Name, ic.Name, rejectedCondition); err != nil {
+		t.Fatalf("failed to observe expected conditions: %v", err)
+	}
+
+	// Update the ingresscontroller wildcard policy to WildcardsAllowed.
+	if err := kclient.Get(context.TODO(), icName, ic); err != nil {
+		t.Fatalf("failed to get ingresscontroller: %v", err)
+	}
+	ic.Spec.RouteAdmission.WildcardPolicy = operatorv1.WildcardPolicyAllowed
+	if err := kclient.Update(context.TODO(), ic); err != nil {
+		t.Fatalf("failed to update ingresscontroller: %v", err)
+	}
+	err = wait.PollImmediate(1*time.Second, 1*time.Minute, func() (bool, error) {
+		deployment := &appsv1.Deployment{}
+		if err := kclient.Get(context.TODO(), controller.RouterDeploymentName(ic), deployment); err != nil {
+			return false, err
+		}
+		for _, v := range deployment.Spec.Template.Spec.Containers[0].Env {
+			if v.Name == "ROUTER_ALLOW_WILDCARD_ROUTES" {
+				return strconv.ParseBool(v.Value)
+			}
+		}
+		return false, nil
+	})
+	if err != nil {
+		t.Fatalf("failed to observe ROUTER_ALLOW_WILDCARD_ROUTES=true: %v", err)
+	}
+	if err := waitForIngressControllerCondition(kclient, 3*time.Minute, icName, conditions...); err != nil {
+		t.Fatalf("failed to observe expected conditions: %v", err)
+	}
+
+	// Recreate the route since the failed route will not automatically get
+	// readmitted and a route wildcard policy is immutable.
+	if err := kclient.Delete(context.TODO(), route4); err != nil {
+		t.Fatalf("failed to delete route: %v", err)
+	}
+	route4 = makeRoute(route4Name, "route4.test.example.com", "/bar")
+	route4.Spec.WildcardPolicy = routev1.WildcardPolicySubdomain
+	if err := kclient.Create(context.TODO(), route4); err != nil {
+		t.Fatalf("failed to create route: %v", err)
+	}
+
+	// The route should now be admitted.
+	if err := waitForRouteIngressConditions(kclient, route4Name, ic.Name, admittedCondition); err != nil {
+		t.Fatalf("failed to observe expected conditions: %v", err)
+	}
+}
+
+func TestSyslogLogging(t *testing.T) {
+	ic := &operatorv1.IngressController{}
+	if err := kclient.Get(context.TODO(), defaultName, ic); err != nil {
+		t.Fatalf("failed to get default ingresscontroller: %v", err)
+	}
+	deployment := &appsv1.Deployment{}
+	if err := kclient.Get(context.TODO(), controller.RouterDeploymentName(ic), deployment); err != nil {
+		t.Fatalf("failed to get default ingresscontroller's deployment: %v", err)
+	}
+	var (
+		image      string
+		foundImage bool
+	)
+	for _, container := range deployment.Spec.Template.Spec.Containers {
+		if container.Name == "router" {
+			image = container.Image
+			foundImage = true
+		}
+	}
+	if !foundImage {
+		t.Fatal("failed to determine default ingresscontroller deployment's image")
+	}
+
+	// Set up rsyslog.
+	syslogPod := &corev1.Pod{
+		ObjectMeta: metav1.ObjectMeta{
+			Namespace: "openshift-ingress",
+			Name:      "syslog",
+		},
+		Spec: corev1.PodSpec{
+			Containers: []corev1.Container{
+				{
+					Name:  "syslog",
+					Image: image,
+					Command: []string{
+						"/sbin/rsyslogd", "-n",
+						"-i", "/tmp/rsyslog.pid",
+						"-f", "/etc/rsyslog/rsyslog.conf",
+					},
+					VolumeMounts: []corev1.VolumeMount{
+						{
+							Name:      "rsyslog-config",
+							MountPath: "/etc/rsyslog",
+						},
+					},
+				},
+			},
+			Volumes: []corev1.Volume{
+				{
+					Name: "rsyslog-config",
+					VolumeSource: corev1.VolumeSource{
+						ConfigMap: &corev1.ConfigMapVolumeSource{
+							LocalObjectReference: corev1.LocalObjectReference{
+								Name: "rsyslog-conf",
+							},
+						},
+					},
+				},
+			},
+		},
+	}
+	if err := kclient.Create(context.TODO(), syslogPod); err != nil {
+		t.Fatalf("failed to create pod for rsyslog: %v", err)
+	}
+	defer func() {
+		if err := kclient.Delete(context.TODO(), syslogPod); err != nil {
+			t.Fatalf("failed to delete pod %s: %v", syslogPod.Name, err)
+		}
+	}()
+	syslogConfigmap := &corev1.ConfigMap{
+		ObjectMeta: metav1.ObjectMeta{
+			Name:      "rsyslog-conf",
+			Namespace: "openshift-ingress",
+		},
+		Data: map[string]string{
+			"rsyslog.conf": `$ModLoad imudp
+$UDPServerRun 10514
+$ModLoad omstdout.so
+*.* :omstdout:
+`,
+		},
+	}
+	if err := kclient.Create(context.TODO(), syslogConfigmap); err != nil {
+		t.Fatalf("failed to create configmap for rsyslog: %v", err)
+	}
+	defer func() {
+		if err := kclient.Delete(context.TODO(), syslogConfigmap); err != nil {
+			t.Fatalf("failed to delete configmap %s: %v", syslogConfigmap.Name, err)
+		}
+	}()
+
+	// Get the rsyslog endpoint.
+	var syslogAddress string
+	err := wait.PollImmediate(1*time.Second, 3*time.Minute, func() (bool, error) {
+		if err := kclient.Get(context.TODO(), types.NamespacedName{Namespace: syslogPod.Namespace, Name: syslogPod.Name}, syslogPod); err != nil {
+			return false, nil
+		}
+		syslogAddress = syslogPod.Status.PodIP
+		if len(syslogAddress) == 0 {
+			return false, nil
+		}
+		return true, nil
+	})
+	if err != nil {
+		t.Fatalf("failed to observe syslog pod IP address: %v", err)
+	}
+
+	// Create an ingresscontroller that logs to the endpoint.
+	icName := types.NamespacedName{Namespace: operatorNamespace, Name: "syslog"}
+	domain := icName.Name + "." + dnsConfig.Spec.BaseDomain
+	ic = newPrivateController(icName, domain)
+	ic.Spec.Logging = &operatorv1.IngressControllerLogging{
+		Access: &operatorv1.AccessLogging{
+			Destination: operatorv1.LoggingDestination{
+				Type: operatorv1.SyslogLoggingDestinationType,
+				Syslog: &operatorv1.SyslogLoggingDestinationParameters{
+					Address: syslogAddress,
+					Port:    uint32(10514),
+				},
+			},
+		},
+	}
+	if err := kclient.Create(context.TODO(), ic); err != nil {
+		t.Fatalf("failed to create ingresscontroller %s: %v", icName, err)
+	}
+	defer assertIngressControllerDeleted(t, kclient, ic)
+	conditions := []operatorv1.OperatorCondition{
+		{Type: operatorv1.IngressControllerAvailableConditionType, Status: operatorv1.ConditionTrue},
+		{Type: operatorv1.LoadBalancerManagedIngressConditionType, Status: operatorv1.ConditionFalse},
+		{Type: operatorv1.DNSManagedIngressConditionType, Status: operatorv1.ConditionFalse},
+	}
+	if err := waitForIngressControllerCondition(kclient, 5*time.Minute, icName, conditions...); err != nil {
+		t.Fatalf("failed to observe expected conditions: %v", err)
+	}
+
+	// Scan the syslog logs to make sure some requests get logged;
+	// the kubelet's health probes should get logged.
+	kubeConfig, err := config.GetConfig()
+	if err != nil {
+		t.Fatalf("failed to get kube config: %v", err)
+	}
+	client, err := kubernetes.NewForConfig(kubeConfig)
+	if err != nil {
+		t.Fatalf("failed to create kube client: %v", err)
+	}
+	err = wait.PollImmediate(1*time.Second, 1*time.Minute, func() (bool, error) {
+		readCloser, err := client.CoreV1().Pods(syslogPod.Namespace).GetLogs(syslogPod.Name, &corev1.PodLogOptions{
+			Container: "syslog",
+			Follow:    false,
+		}).Stream(context.TODO())
+		if err != nil {
+			t.Errorf("failed to read logs from syslog: %v", err)
+			return false, nil
+		}
+		defer func() {
+			if err := readCloser.Close(); err != nil {
+				t.Errorf("failed to close logs reader: %v", err)
+			}
+		}()
+		scanner := bufio.NewScanner(readCloser)
+		for scanner.Scan() {
+			line := scanner.Text()
+			if strings.Contains(line, " HTTP/1.1") {
+				t.Logf("found log message for request: %s", line)
+				return true, nil
+			}
+		}
+		return false, nil
+	})
+	if err != nil {
+		t.Fatalf("failed to observe any request logged in syslog: %v", err)
+	}
+}
+
+func TestContainerLogging(t *testing.T) {
+	icName := types.NamespacedName{Namespace: operatorNamespace, Name: "containerlogging"}
+	domain := icName.Name + "." + dnsConfig.Spec.BaseDomain
+	ic := newPrivateController(icName, domain)
+	ic.Spec.Logging = &operatorv1.IngressControllerLogging{
+		Access: &operatorv1.AccessLogging{
+			Destination: operatorv1.LoggingDestination{
+				Type:      operatorv1.ContainerLoggingDestinationType,
+				Container: &operatorv1.ContainerLoggingDestinationParameters{},
+			},
+		},
+	}
+	if err := kclient.Create(context.TODO(), ic); err != nil {
+		t.Fatalf("failed to create ingresscontroller %s: %v", icName, err)
+	}
+	defer assertIngressControllerDeleted(t, kclient, ic)
+	conditions := []operatorv1.OperatorCondition{
+		{Type: operatorv1.IngressControllerAvailableConditionType, Status: operatorv1.ConditionTrue},
+		{Type: operatorv1.LoadBalancerManagedIngressConditionType, Status: operatorv1.ConditionFalse},
+		{Type: operatorv1.DNSManagedIngressConditionType, Status: operatorv1.ConditionFalse},
+	}
+	if err := waitForIngressControllerCondition(kclient, 5*time.Minute, icName, conditions...); err != nil {
+		t.Fatalf("failed to observe expected conditions: %v", err)
+	}
 }
 
 func newLoadBalancerController(name types.NamespacedName, domain string) *operatorv1.IngressController {
